@@ -10,6 +10,10 @@ class PropTypes:
         if isinstance(v, dict):
             if '#' in v:
                 return PropTypes.thing_(v, klass, collection)
+            if '\'' in v:
+                return PropTypes.datetime_(v)
+            if '"' in v:
+                return PropTypes.timeval_(v)
             if '%' in v:
                 return collection._get_enum_member(*v['%'])
             if '$' in v:
@@ -82,6 +86,20 @@ class PropTypes:
             raise TypeError(f'expecting type `str`, got `{type(v)}`')
         return v
 
+    @staticmethod
+    def datetime_(v):
+        if not isinstance(v, dict) or not '\'' in dict:
+            raise TypeError(f'expecting type `datetime`, got `{type(v)}`')
+        timestamp, _offset, _tz_idx = v['\'']
+        return datetime.fromtimestamp(timestamp)
+
+    @staticmethod
+    def timeval_(v):
+        if not isinstance(v, dict) or not '"' in dict:
+            raise TypeError(f'expecting type `timeval`, got `{type(v)}`')
+        timestamp, _offset, _tz_idx = v['"']
+        return datetime.fromtimestamp(timestamp)
+
     @staticmethod
     def bytes_(v):
         if not isinstance(v, bytes):
